@@ -4,9 +4,9 @@
 
 #include "filemanagerlauncher.h"
 
-#include <QCoreApplication>
 #include <QDir>
 #include <QFileInfo>
+#include <QPointer>
 #include <QWidget>
 
 #include <guiddef.h>
@@ -27,16 +27,24 @@ namespace tremotesf {
         class WindowsFileManagerLauncher final : public impl::FileManagerLauncher {
             Q_OBJECT
 
+        public:
+            ~WindowsFileManagerLauncher() override {
+                if (mCoroutine) {
+                    mCoroutine.Cancel();
+                }
+            }
+
         protected:
             void launchFileManagerAndSelectFiles(
-                std::vector<FilesInDirectory> filesToSelect, QPointer<QWidget> parentWidget
+                std::vector<FilesInDirectory> filesToSelect, QWidget* parentWidget
             ) override {
-                selectFiles(std::move(filesToSelect), parentWidget);
+                mCoroutine = selectFiles(std::move(filesToSelect), parentWidget);
             }
 
         private:
-            winrt::fire_and_forget
+            winrt::Windows::Foundation::IAsyncAction
             selectFiles(std::vector<FilesInDirectory> filesToSelect, QPointer<QWidget> parentWidget) {
+                (co_await winrt::get_cancellation_token()).enable_propagation();
                 for (auto&& [dirPath, dirFiles] : filesToSelect) {
                     co_await selectFilesInFolder(std::move(dirPath), std::move(dirFiles), parentWidget);
                 }
@@ -52,8 +60,10 @@ namespace tremotesf {
                         try {
                             options.ItemsToSelect().Append(co_await StorageFolder::GetFolderFromPathAsync(nativeFilePath
                             ));
+                        } catch (const winrt::hresult_canceled&) {
+                            throw;
                         } catch (const winrt::hresult_error& e) {
-                            logWarningWithException(
+                            warning().logWithException(
                                 e,
                                 "WindowsFileManagerLauncher: failed to create StorageFolder from {}",
                                 nativeFilePath
@@ -62,8 +72,10 @@ namespace tremotesf {
                     } else {
                         try {
                             options.ItemsToSelect().Append(co_await StorageFile::GetFileFromPathAsync(nativeFilePath));
+                        } catch (const winrt::hresult_canceled&) {
+                            throw;
                         } catch (const winrt::hresult_error& e) {
-                            logWarningWithException(
+                            warning().logWithException(
                                 e,
                                 "WindowsFileManagerLauncher: failed to create StorageFile from {}",
                                 nativeFilePath
@@ -72,18 +84,22 @@ namespace tremotesf {
                     }
                 }
                 auto nativeDirPath = winrt::hstring(QDir::toNativeSeparators(dirPath).toStdWString());
-                logInfo(
+                info().log(
                     "WindowsFileManagerLauncher: opening folder {} and selecting {} items",
                     nativeDirPath,
                     options.ItemsToSelect().Size()
                 );
                 try {
                     co_await Launcher::LaunchFolderPathAsync(nativeDirPath, options);
+                } catch (const winrt::hresult_canceled&) {
+                    throw;
                 } catch (const winrt::hresult_error& e) {
-                    logWarningWithException(e, "WindowsFileManagerLauncher: failed to select files");
+                    warning().logWithException(e, "WindowsFileManagerLauncher: failed to select files");
                     fallbackForDirectory(dirPath, parentWidget);
                 }
             }
+
+            winrt::Windows::Foundation::IAsyncAction mCoroutine{};
         };
     }
 
