@@ -36,9 +36,7 @@ private slots:
         printlnStdout("foo");
         printlnStdout("{}", "foo");
         printlnStdout(FMT_STRING("{}"), "foo");
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), "foo");
-#endif
     }
 
     void stdoutStdString() {
@@ -46,9 +44,7 @@ private slots:
         printlnStdout(str);
         printlnStdout("{}", str);
         printlnStdout(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), str);
-#endif
     }
 
     void stdoutStdStringView() {
@@ -56,9 +52,7 @@ private slots:
         printlnStdout(str);
         printlnStdout("{}", str);
         printlnStdout(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), str);
-#endif
     }
 
     void stdoutQString() {
@@ -66,9 +60,7 @@ private slots:
         printlnStdout(str);
         printlnStdout("{}", str);
         printlnStdout(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), str);
-#endif
     }
 
     void stdoutQStringView() {
@@ -77,9 +69,7 @@ private slots:
         printlnStdout(str);
         printlnStdout("{}", str);
         printlnStdout(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), str);
-#endif
     }
 
     void stdoutQLatin1String() {
@@ -87,9 +77,7 @@ private slots:
         printlnStdout(str);
         printlnStdout("{}", str);
         printlnStdout(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), str);
-#endif
     }
 
 #if QT_VERSION_MAJOR >= 6
@@ -98,9 +86,7 @@ private slots:
         printlnStdout(str);
         printlnStdout("{}", str);
         printlnStdout(FMT_STRING("{}"), str);
-#    if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), str);
-#    endif
     }
 
     void stdoutQAnyStringView() {
@@ -108,9 +94,7 @@ private slots:
         printlnStdout(str);
         printlnStdout("{}", str);
         printlnStdout(FMT_STRING("{}"), str);
-#    if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), str);
-#    endif
     }
 #endif
 
@@ -119,9 +103,7 @@ private slots:
         printlnStdout(value);
         printlnStdout("{}", value);
         printlnStdout(FMT_STRING("{}"), value);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), value);
-#endif
     }
 
     void stdoutQStringList() {
@@ -129,9 +111,7 @@ private slots:
         printlnStdout(list);
         printlnStdout("{}", list);
         printlnStdout(FMT_STRING("{}"), list);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), list);
-#endif
     }
 
     void stdoutTorrent() {
@@ -139,18 +119,14 @@ private slots:
         printlnStdout(value);
         printlnStdout("{}", value);
         printlnStdout(FMT_STRING("{}"), value);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), value);
-#endif
     }
 
     void stdoutThis() {
         printlnStdout(*this);
         printlnStdout("{}", *this);
         printlnStdout(FMT_STRING("{}"), *this);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), *this);
-#endif
     }
 
     void stdoutQObject() {
@@ -158,150 +134,122 @@ private slots:
         printlnStdout(value);
         printlnStdout("{}", value);
         printlnStdout(FMT_STRING("{}"), value);
-#if FMT_VERSION >= 80000
         printlnStdout(fmt::runtime("{}"), value);
-#endif
     }
 
     void infoStringLiteral() {
-        logInfo("foo");
-        logInfo("{}", "foo");
-        logInfo(FMT_STRING("{}"), "foo");
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), "foo");
-#endif
+        info().log("foo");
+        info().log("{}", "foo");
+        info().log(FMT_STRING("{}"), "foo");
+        info().log(fmt::runtime("{}"), "foo");
     }
 
     void infoStdString() {
         const std::string str = "foo";
-        logInfo(str);
-        logInfo("{}", str);
-        logInfo(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), str);
-#endif
+        info().log(str);
+        info().log("{}", str);
+        info().log(FMT_STRING("{}"), str);
+        info().log(fmt::runtime("{}"), str);
     }
 
     void infoStdStringView() {
         const std::string_view str = "foo";
-        logInfo(str);
-        logInfo("{}", str);
-        logInfo(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), str);
-#endif
+        info().log(str);
+        info().log("{}", str);
+        info().log(FMT_STRING("{}"), str);
+        info().log(fmt::runtime("{}"), str);
     }
 
     void infoQString() {
         const QString str = "foo";
-        logInfo(str);
-        logInfo("{}", str);
-        logInfo(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), str);
-#endif
+        info().log(str);
+        info().log("{}", str);
+        info().log(FMT_STRING("{}"), str);
+        info().log(fmt::runtime("{}"), str);
     }
 
     void infoQStringView() {
         const QString _str = "foo";
         const QStringView str = _str;
-        logInfo(str);
-        logInfo("{}", str);
-        logInfo(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), str);
-#endif
+        info().log(str);
+        info().log("{}", str);
+        info().log(FMT_STRING("{}"), str);
+        info().log(fmt::runtime("{}"), str);
     }
 
     void infoQLatin1String() {
         const auto str = "foo"_l1;
-        logInfo(str);
-        logInfo("{}", str);
-        logInfo(FMT_STRING("{}"), str);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), str);
-#endif
+        info().log(str);
+        info().log("{}", str);
+        info().log(FMT_STRING("{}"), str);
+        info().log(fmt::runtime("{}"), str);
     }
 
 #if QT_VERSION_MAJOR >= 6
     void infoQUtf8StringView() {
         const QUtf8StringView str = "foo";
-        logInfo(str);
-        logInfo("{}", str);
-        logInfo(FMT_STRING("{}"), str);
-#    if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), str);
-#    endif
+        info().log(str);
+        info().log("{}", str);
+        info().log(FMT_STRING("{}"), str);
+        info().log(fmt::runtime("{}"), str);
     }
 
     void infoQAnyStringView() {
         const QAnyStringView str = "foo";
-        logInfo(str);
-        logInfo("{}", str);
-        logInfo(FMT_STRING("{}"), str);
-#    if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), str);
-#    endif
+        info().log(str);
+        info().log("{}", str);
+        info().log(FMT_STRING("{}"), str);
+        info().log(fmt::runtime("{}"), str);
     }
 #endif
 
     void infoQVariant() {
         const QVariant value = "foo";
-        logInfo(value);
-        logInfo("{}", value);
-        logInfo(FMT_STRING("{}"), value);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), value);
-#endif
+        info().log(value);
+        info().log("{}", value);
+        info().log(FMT_STRING("{}"), value);
+        info().log(fmt::runtime("{}"), value);
     }
 
     void infoQStringList() {
         const QStringList list{"foo"};
-        logInfo(list);
-        logInfo("{}", list);
-        logInfo(FMT_STRING("{}"), list);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), list);
-#endif
+        info().log(list);
+        info().log("{}", list);
+        info().log(FMT_STRING("{}"), list);
+        info().log(fmt::runtime("{}"), list);
     }
 
     void infoTorrent() {
         const Torrent value{};
-        logInfo(value);
-        logInfo("{}", value);
-        logInfo(FMT_STRING("{}"), value);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), value);
-#endif
+        info().log(value);
+        info().log("{}", value);
+        info().log(FMT_STRING("{}"), value);
+        info().log(fmt::runtime("{}"), value);
     }
 
     void infoThis() {
-        logInfo(*this);
-        logInfo("{}", *this);
-        logInfo(FMT_STRING("{}"), *this);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), *this);
-#endif
+        info().log(*this);
+        info().log("{}", *this);
+        info().log(FMT_STRING("{}"), *this);
+        info().log(fmt::runtime("{}"), *this);
     }
 
     void infoQObject() {
         QObject value{};
-        logInfo(value);
-        logInfo("{}", value);
-        logInfo(FMT_STRING("{}"), value);
-#if FMT_VERSION >= 80000
-        logInfo(fmt::runtime("{}"), value);
-#endif
+        info().log(value);
+        info().log("{}", value);
+        info().log(FMT_STRING("{}"), value);
+        info().log(fmt::runtime("{}"), value);
     }
 
     void warningStdException() {
         const std::runtime_error e("nope");
-        logWarning(e);
+        warning().log(e);
     }
 
     void warningWithStdException() {
         const std::runtime_error e("nope");
-        logWarningWithException(e, "oh no");
+        warning().logWithException(e, "oh no");
     }
 
     void warningNested() {
@@ -312,7 +260,7 @@ private slots:
                 std::throw_with_nested(std::runtime_error("higher-level nope"));
             }
         } catch (const std::runtime_error& e) {
-            logWarning(e);
+            warning().log(e);
         }
     }
 
@@ -324,19 +272,19 @@ private slots:
                 std::throw_with_nested(std::runtime_error("higher-level nope"));
             }
         } catch (const std::runtime_error& e) {
-            logWarningWithException(e, "oh no");
+            warning().logWithException(e, "oh no");
         }
     }
 
 #ifdef Q_OS_WIN
     void warningHresultError() {
         winrt::hresult_error e(E_ACCESSDENIED);
-        logWarning(e);
+        warning().log(e);
     }
 
     void warningWithHresultError() {
         winrt::hresult_error e(E_ACCESSDENIED);
-        logWarningWithException(e, "oh no");
+        warning().logWithException(e, "oh no");
     }
 
     void warningHresultErrorNested() {
@@ -347,7 +295,7 @@ private slots:
                 std::throw_with_nested(std::runtime_error("higher-level nope"));
             }
         } catch (const std::runtime_error& e) {
-            logWarning(e);
+            warning().log(e);
         }
     }
 
@@ -359,7 +307,7 @@ private slots:
                 std::throw_with_nested(std::runtime_error("higher-level nope"));
             }
         } catch (const std::runtime_error& e) {
-            logWarningWithException(e, "oh no");
+            warning().logWithException(e, "oh no");
         }
     }
 #endif
