@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015-2023 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -11,10 +11,9 @@ namespace tremotesf {
     class Rpc;
     class Torrent;
 
-    bool isIncompleteDirectoryMounted(const Rpc* rpc);
-    bool isTorrentLocalMounted(const Rpc* rpc, const Torrent* torrent);
+    bool isServerLocalOrTorrentIsMounted(const Rpc* rpc, const Torrent* torrent);
     QString localTorrentDownloadDirectoryPath(const Rpc* rpc, const Torrent* torrent);
-    QString localTorrentFilesPath(const Rpc* rpc, const Torrent* torrent);
+    QString localTorrentRootFilePath(const Rpc* rpc, const Torrent* torrent);
 }
 
 #endif // TREMOTESF_RPC_MOUNTEDDIRECTORIESUTILS_H
