@@ -12,9 +12,7 @@ class QJsonObject;
 
 namespace tremotesf {
     struct Peer {
-#ifndef SWIG
         static constexpr auto addressKey = "address"_l1;
-#endif
 
         explicit Peer(QString&& address, const QJsonObject& peerJson);
         bool update(const QJsonObject& peerJson);
