@@ -137,11 +137,16 @@ namespace tremotesf {
             std::map<QString, QString> renamedFiles,
             TorrentData::Priority bandwidthPriority,
             bool start,
-            DeleteFileMode deleteFileMode
+            DeleteFileMode deleteFileMode,
+            std::vector<QString> labels
         );
 
         void addTorrentLinks(
-            QStringList links, QString downloadDirectory, TorrentData::Priority bandwidthPriority, bool start
+            QStringList links,
+            QString downloadDirectory,
+            TorrentData::Priority bandwidthPriority,
+            bool start,
+            std::vector<QString> labels
         );
 
         void startTorrents(std::span<const int> ids);
@@ -160,6 +165,7 @@ namespace tremotesf {
         void setSessionProperties(QJsonObject properties);
         void setTorrentProperty(int id, QString property, QJsonValue value, bool updateIfSuccessful = false);
         void setTorrentsLocation(std::span<const int> ids, QString location, bool moveFiles);
+        void setTorrentsLabels(std::span<const int> ids, std::span<const QString> labels);
         void getTorrentFiles(int torrentId);
         void getTorrentPeers(int torrentId);
 
@@ -186,12 +192,19 @@ namespace tremotesf {
             std::map<QString, QString> renamedFiles,
             TorrentData::Priority bandwidthPriority,
             bool start,
-            DeleteFileMode deleteFileMode
+            DeleteFileMode deleteFileMode,
+            std::vector<QString> labels
         );
         Coroutine<> addTorrentLinksImpl(
-            QStringList links, QString downloadDirectory, TorrentData::Priority bandwidthPriority, bool start
+            QStringList links,
+            QString downloadDirectory,
+            TorrentData::Priority bandwidthPriority,
+            bool start,
+            std::vector<QString> labels
+        );
+        Coroutine<> addTorrentLinkImpl(
+            QString link, QString downloadDirectory, int bandwidthPriority, bool start, std::vector<QString> labels
         );
-        Coroutine<> addTorrentLinkImpl(QString link, QString downloadDirectory, int bandwidthPriority, bool start);
         Coroutine<> getTorrentsFiles(QJsonArray ids);
         Coroutine<> getTorrentsPeers(QJsonArray ids);
         Coroutine<> renameTorrentFileImpl(int torrentId, QString filePath, QString newName);
@@ -220,6 +233,7 @@ namespace tremotesf {
         bool mAutoReconnectEnabled{};
 
         std::optional<bool> mServerIsLocal{};
+        QByteArray mGetTorrentsRequestData{};
 
         std::chrono::seconds mUpdateInterval{};
         std::chrono::seconds mAutoReconnectInterval{};
