@@ -15,6 +15,8 @@
 class QSettings;
 
 namespace tremotesf {
+    enum class PathOs;
+
     struct MountedDirectory {
         QString localPath{};
         QString remotePath{};
@@ -49,6 +51,8 @@ namespace tremotesf {
         Q_OBJECT
 
     public:
+        explicit Servers(QSettings* settings, QObject* parent);
+
         static Servers* instance();
 
         bool hasServers() const;
@@ -60,7 +64,9 @@ namespace tremotesf {
         void setCurrentServer(const QString& name);
 
         bool currentServerHasMountedDirectories() const;
+        QString fromLocalToRemoteDirectory(const QString& localPath, PathOs pathOs);
         QString fromLocalToRemoteDirectory(const QString& localPath, const ServerSettings* serverSettings);
+        QString fromRemoteToLocalDirectory(const QString& remotePath, PathOs pathOs);
         QString fromRemoteToLocalDirectory(const QString& remotePath, const ServerSettings* serverSettings);
 
         LastTorrents currentServerLastTorrents() const;
@@ -109,7 +115,6 @@ namespace tremotesf {
         void sync();
 
     private:
-        explicit Servers(QObject* parent = nullptr);
         Server getServer(const QString& name) const;
         void updateMountedDirectories();
 
