@@ -71,6 +71,9 @@ namespace tremotesf {
         CreationDate,
         Comment,
         TrackerStats,
+        FileCount,
+        Labels,
+
         Count
     };
 
@@ -165,6 +168,10 @@ namespace tremotesf {
                 return "comment"_l1;
             case TorrentData::UpdateKey::TrackerStats:
                 return "trackerStats"_l1;
+            case TorrentData::UpdateKey::FileCount:
+                return "file-count"_l1;
+            case TorrentData::UpdateKey::Labels:
+                return "labels"_l1;
             case TorrentData::UpdateKey::Count:
                 return {};
             }
@@ -446,6 +453,19 @@ namespace tremotesf {
             setChanged(totalLeechersFromTrackersCount, newTotalLeechers, changed);
             return;
         }
+        case TorrentData::UpdateKey::FileCount:
+            setChanged(singleFile, value.toInt() == 1, changed);
+            return;
+        case TorrentData::UpdateKey::Labels: {
+            setChanged(
+                labels,
+                toContainer<std::vector>(value.toArray() | std::views::transform([](auto value) {
+                                             return value.toString();
+                                         })),
+                changed
+            );
+            return;
+        }
         case TorrentData::UpdateKey::Count:
             throw std::logic_error("UpdateKey::Count should not be mapped");
         }
@@ -487,10 +507,16 @@ namespace tremotesf {
         [[maybe_unused]] const bool changed = mData.update(keys, values, true, rpc);
     }
 
-    QJsonArray Torrent::updateFields() {
+    QJsonArray Torrent::updateFields(const ServerSettings* serverSettings) {
         QJsonArray fields{};
         for (int i = 0; i < static_cast<int>(TorrentData::UpdateKey::Count); ++i) {
             const auto key = static_cast<TorrentData::UpdateKey>(i);
+            if (key == TorrentData::UpdateKey::FileCount && !serverSettings->data().hasFileCountProperty()) {
+                continue;
+            }
+            if (key == TorrentData::UpdateKey::Labels && !serverSettings->data().hasLabelsProperty()) {
+                continue;
+            }
             fields.push_back(updateKeyString(key));
         }
         return fields;
@@ -819,7 +845,7 @@ namespace tremotesf {
                 return std::ranges::find(newPeers, peer.address, &NewPeer::address);
             }
 
-            void onAboutToRemoveItems(size_t, size_t) override{};
+            void onAboutToRemoveItems(size_t, size_t) override {};
 
             void onRemovedItems(size_t first, size_t last) override {
                 removedIndexRanges.emplace_back(static_cast<int>(first), static_cast<int>(last));
