@@ -9,8 +9,6 @@
 #include <QObject>
 #include <QString>
 
-#include "log/formatters.h"
-
 class QJsonObject;
 
 namespace tremotesf {
@@ -33,6 +31,4 @@ namespace tremotesf {
     };
 }
 
-SPECIALIZE_FORMATTER_FOR_Q_ENUM(tremotesf::TorrentFile::Priority)
-
 #endif // TREMOTESF_RPC_TORRENTFILE_H
