@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015-2023 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -7,7 +7,9 @@
 #include "ui/itemmodels/basetorrentfilesmodel.h"
 
 namespace tremotesf {
-    TorrentFilesProxyModel::TorrentFilesProxyModel(BaseTorrentFilesModel* sourceModel, int sortRole, int fallbackColumn, QObject* parent)
+    TorrentFilesProxyModel::TorrentFilesProxyModel(
+        BaseTorrentFilesModel* sourceModel, int sortRole, int fallbackColumn, QObject* parent
+    )
         : BaseProxyModel(sourceModel, sortRole, fallbackColumn, parent) {}
 
     bool TorrentFilesProxyModel::lessThan(const QModelIndex& left, const QModelIndex& right) const {
