@@ -1,11 +1,12 @@
-// SPDX-FileCopyrightText: 2015-2023 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "notificationscontroller.h"
 
 namespace tremotesf {
-    NotificationsController* NotificationsController::createInstance(QSystemTrayIcon* trayIcon, const Rpc* rpc, QObject* parent) {
+    NotificationsController*
+    NotificationsController::createInstance(QSystemTrayIcon* trayIcon, const Rpc* rpc, QObject* parent) {
         return new NotificationsController(trayIcon, rpc, parent);
     }
 }
