@@ -16,21 +16,13 @@ namespace tremotesf {
     public:
         static constexpr auto TrackerRole = Qt::UserRole;
 
-        inline explicit AllTrackersModel(QObject* parent = nullptr) : BaseTorrentsFiltersSettingsModel(parent){};
+        inline explicit AllTrackersModel(QObject* parent = nullptr) : BaseTorrentsFiltersSettingsModel(parent) {};
 
         QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
         int rowCount(const QModelIndex& = {}) const override;
-        bool removeRows(int row, int count, const QModelIndex& parent = {}) override;
-
-        QModelIndex indexForTracker(const QString& tracker) const;
 
         QModelIndex indexForTorrentsProxyModelFilter() const override;
 
-        using QAbstractItemModel::beginInsertRows;
-        using QAbstractItemModel::beginRemoveRows;
-        using QAbstractItemModel::endInsertRows;
-        using QAbstractItemModel::endRemoveRows;
-
         struct TrackerItem {
             QString tracker;
             int torrents;
