@@ -10,15 +10,28 @@
 #include <QIcon>
 #include <QMetaEnum>
 
-#include "stdutils.h"
-#include "rpc/torrent.h"
+#include "rpc/pathutils.h"
 #include "rpc/rpc.h"
+#include "rpc/serversettings.h"
+#include "rpc/torrent.h"
 #include "desktoputils.h"
 #include "formatutils.h"
+#include "settings.h"
+#include "stdutils.h"
 
 namespace tremotesf {
     TorrentsModel::TorrentsModel(Rpc* rpc, QObject* parent) : QAbstractTableModel(parent), mRpc(nullptr) {
         setRpc(rpc);
+
+        const auto settings = Settings::instance();
+        mUseRelativeTime = settings->get_displayRelativeTime();
+        QObject::connect(settings, &Settings::displayRelativeTimeChanged, this, [this, settings] {
+            mUseRelativeTime = settings->get_displayRelativeTime();
+        });
+        mDisplayFullDownloadDirectoryPath = settings->get_displayFullDownloadDirectoryPath();
+        QObject::connect(settings, &Settings::displayFullDownloadDirectoryPathChanged, this, [this, settings] {
+            mDisplayFullDownloadDirectoryPath = settings->get_displayFullDownloadDirectoryPath();
+        });
     }
 
     int TorrentsModel::columnCount(const QModelIndex&) const { return QMetaEnum::fromType<Column>().keyCount(); }
@@ -152,9 +165,17 @@ namespace tremotesf {
             case Column::Ratio:
                 return formatutils::formatRatio(torrent->data().ratio);
             case Column::AddedDate:
-                return torrent->data().addedDate.toLocalTime();
+                return formatutils::formatDateTime(
+                    torrent->data().addedDate.toLocalTime(),
+                    QLocale::ShortFormat,
+                    mUseRelativeTime
+                );
             case Column::DoneDate:
-                return torrent->data().doneDate.toLocalTime();
+                return formatutils::formatDateTime(
+                    torrent->data().doneDate.toLocalTime(),
+                    QLocale::ShortFormat,
+                    mUseRelativeTime
+                );
             case Column::DownloadSpeedLimit:
                 if (torrent->data().downloadSpeedLimited) {
                     return formatutils::formatSpeedLimit(torrent->data().downloadSpeedLimit);
@@ -172,11 +193,18 @@ namespace tremotesf {
             case Column::LeftUntilDone:
                 return formatutils::formatByteSize(torrent->data().leftUntilDone);
             case Column::DownloadDirectory:
-                return torrent->data().downloadDirectory;
+                if (mDisplayFullDownloadDirectoryPath) {
+                    return toNativeSeparators(torrent->data().downloadDirectory, mRpc->serverSettings()->data().pathOs);
+                }
+                return lastPathSegment(torrent->data().downloadDirectory);
             case Column::CompletedSize:
                 return formatutils::formatByteSize(torrent->data().completedSize);
             case Column::ActivityDate:
-                return torrent->data().activityDate.toLocalTime();
+                return formatutils::formatDateTime(
+                    torrent->data().activityDate.toLocalTime(),
+                    QLocale::ShortFormat,
+                    mUseRelativeTime
+                );
             default:
                 break;
             }
@@ -187,9 +215,10 @@ namespace tremotesf {
             case Column::Status:
             case Column::AddedDate:
             case Column::DoneDate:
-            case Column::DownloadDirectory:
             case Column::ActivityDate:
                 return data(index, Qt::DisplayRole);
+            case Column::DownloadDirectory:
+                return torrent->data().downloadDirectory;
             default:
                 break;
             }
@@ -255,6 +284,9 @@ namespace tremotesf {
                 return Qt::ElideMiddle;
             }
             return Qt::ElideRight;
+        case static_cast<int>(Role::AlwaysShowTooltip):
+            return static_cast<Column>(index.column()) == Column::DownloadDirectory &&
+                   !mDisplayFullDownloadDirectoryPath;
         default:
             break;
         }
