@@ -2,6 +2,8 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
+#include <algorithm>
+
 #include "torrentsproxymodel.h"
 
 #include "rpc/torrent.h"
@@ -17,12 +19,14 @@ namespace tremotesf {
               static_cast<int>(TorrentsModel::Column::Name),
               parent
           ),
-          mStatusFilterEnabled(Settings::instance()->isTorrentsStatusFilterEnabled()),
-          mStatusFilter(Settings::instance()->torrentsStatusFilter()),
-          mTrackerFilterEnabled(Settings::instance()->isTorrentsTrackerFilterEnabled()),
-          mTrackerFilter(Settings::instance()->torrentsTrackerFilter()),
-          mDownloadDirectoryFilterEnabled(Settings::instance()->isTorrentsDownloadDirectoryFilterEnabled()),
-          mDownloadDirectoryFilter(Settings::instance()->torrentsDownloadDirectoryFilter()) {}
+          mStatusFilterEnabled(Settings::instance()->get_torrentsStatusFilterEnabled()),
+          mStatusFilter(Settings::instance()->get_torrentsStatusFilter()),
+          mLabelFilterEnabled(Settings::instance()->get_torrentsLabelFilterEnabled()),
+          mLabelFilter(Settings::instance()->get_torrentsLabelFilter()),
+          mTrackerFilterEnabled(Settings::instance()->get_torrentsTrackerFilterEnabled()),
+          mTrackerFilter(Settings::instance()->get_torrentsTrackerFilter()),
+          mDownloadDirectoryFilterEnabled(Settings::instance()->get_torrentsDownloadDirectoryFilterEnabled()),
+          mDownloadDirectoryFilter(Settings::instance()->get_torrentsDownloadDirectoryFilter()) {}
 
     QString TorrentsProxyModel::searchString() const { return mSearchString; }
 
@@ -39,7 +43,7 @@ namespace tremotesf {
         if (enabled != mStatusFilterEnabled) {
             mStatusFilterEnabled = enabled;
             invalidateFilter();
-            Settings::instance()->setTorrentsStatusFilterEnabled(mStatusFilterEnabled);
+            Settings::instance()->set_torrentsStatusFilterEnabled(mStatusFilterEnabled);
         }
     }
 
@@ -50,7 +54,28 @@ namespace tremotesf {
             mStatusFilter = filter;
             invalidateFilter();
             emit statusFilterChanged();
-            Settings::instance()->setTorrentsStatusFilter(mStatusFilter);
+            Settings::instance()->set_torrentsStatusFilter(mStatusFilter);
+        }
+    }
+
+    bool TorrentsProxyModel::isLabelFilterEnabled() const { return mLabelFilterEnabled; }
+
+    void TorrentsProxyModel::setLabelFilterEnabled(bool enabled) {
+        if (enabled != mLabelFilterEnabled) {
+            mLabelFilterEnabled = enabled;
+            invalidateFilter();
+            Settings::instance()->set_torrentsLabelFilterEnabled(mLabelFilterEnabled);
+        }
+    }
+
+    QString TorrentsProxyModel::labelFilter() const { return mLabelFilter; }
+
+    void TorrentsProxyModel::setLabelFilter(const QString& filter) {
+        if (filter != mLabelFilter) {
+            mLabelFilter = filter;
+            invalidateFilter();
+            emit labelFilterChanged();
+            Settings::instance()->set_torrentsLabelFilter(mLabelFilter);
         }
     }
 
@@ -60,7 +85,7 @@ namespace tremotesf {
         if (enabled != mTrackerFilterEnabled) {
             mTrackerFilterEnabled = enabled;
             invalidateFilter();
-            Settings::instance()->setTorrentsTrackerFilterEnabled(mTrackerFilterEnabled);
+            Settings::instance()->set_torrentsTrackerFilterEnabled(mTrackerFilterEnabled);
         }
     }
 
@@ -71,7 +96,7 @@ namespace tremotesf {
             mTrackerFilter = filter;
             invalidateFilter();
             emit trackerFilterChanged();
-            Settings::instance()->setTorrentsTrackerFilter(mTrackerFilter);
+            Settings::instance()->set_torrentsTrackerFilter(mTrackerFilter);
         }
     }
 
@@ -81,7 +106,7 @@ namespace tremotesf {
         if (enabled != mDownloadDirectoryFilterEnabled) {
             mDownloadDirectoryFilterEnabled = enabled;
             invalidateFilter();
-            Settings::instance()->setTorrentsDownloadDirectoryFilterEnabled(mDownloadDirectoryFilterEnabled);
+            Settings::instance()->set_torrentsDownloadDirectoryFilterEnabled(mDownloadDirectoryFilterEnabled);
         }
     }
 
@@ -92,7 +117,7 @@ namespace tremotesf {
             mDownloadDirectoryFilter = filter;
             invalidateFilter();
             emit downloadDirectoryFilterChanged();
-            Settings::instance()->setTorrentsDownloadDirectoryFilter(mDownloadDirectoryFilter);
+            Settings::instance()->set_torrentsDownloadDirectoryFilter(mDownloadDirectoryFilter);
         }
     }
 
@@ -129,37 +154,36 @@ namespace tremotesf {
     }
 
     bool TorrentsProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex&) const {
-        bool accepts = true;
-
         const Torrent* torrent = static_cast<TorrentsModel*>(sourceModel())->torrentAtRow(sourceRow);
 
         if (!mSearchString.isEmpty() && !torrent->data().name.contains(mSearchString, Qt::CaseInsensitive)) {
-            accepts = false;
+            return false;
         }
 
         if (mStatusFilterEnabled && !statusFilterAcceptsTorrent(torrent, mStatusFilter)) {
-            accepts = false;
+            return false;
+        }
+
+        if (mLabelFilterEnabled && !mLabelFilter.isEmpty()) {
+            const auto matchingLabel = std::ranges::find(torrent->data().labels, mLabelFilter);
+            if (matchingLabel == torrent->data().labels.end()) {
+                return false;
+            }
         }
 
         if (mTrackerFilterEnabled && !mTrackerFilter.isEmpty()) {
-            bool found = false;
-            for (const Tracker& tracker : torrent->data().trackers) {
-                if (tracker.site() == mTrackerFilter) {
-                    found = true;
-                    break;
-                }
-            }
-            if (!found) {
-                accepts = false;
+            const auto matchingTracker = std::ranges::find(torrent->data().trackers, mTrackerFilter, &Tracker::site);
+            if (matchingTracker == torrent->data().trackers.end()) {
+                return false;
             }
         }
 
         if (mDownloadDirectoryFilterEnabled && !mDownloadDirectoryFilter.isEmpty()) {
             if (torrent->data().downloadDirectory != mDownloadDirectoryFilter) {
-                accepts = false;
+                return false;
             }
         }
 
-        return accepts;
+        return true;
     }
 }
